@@ -3,7 +3,7 @@ Forms to be used for djangoapps extending edx_rbac.
 """
 
 from django import forms
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from edx_rbac.fields import UserFromEmailField
 
